Serializes the same portable recipe representation as
recipe_export_json to a YAML string or file.
Value
If file is NULL, returns a YAML string. Otherwise
writes to file and returns the file path invisibly.
Serializes the same portable recipe representation as
recipe_export_json to a YAML string or file.
If file is NULL, returns a YAML string. Otherwise
writes to file and returns the file path invisibly.