Scans other outputs in the plan for concept IDs and produces a lookup table with concept names, domains, vocabulary IDs, and which outputs reference each concept. Useful for translating numeric concept IDs in other output tables into human-readable labels.
Examples
if (FALSE) { # \dontrun{
plan <- ds.omop.plan()
plan <- ds.omop.plan.events(plan, "conditions", "condition_occurrence",
concept_set = c(201826))
plan <- ds.omop.plan.concept_dictionary(plan)
} # }