Create a binary (presence/absence) feature specification
Source:R/feature.R
omop.feature.boolean.RdProduces a feature spec that generates a boolean column indicating
whether the person has any records matching the concept set. When
used in a plan or recipe, the resulting column will contain
TRUE (at least one matching record) or FALSE (no
matching records).
Examples
if (FALSE) { # \dontrun{
spec <- omop.feature.boolean(c(201826))
plan <- ds.omop.plan.features(plan, "has_diabetes",
"condition_occurrence", specs = list(diabetes = spec))
} # }