Produces a feature spec that generates an integer column containing the number of records per person matching the concept set. Useful for quantifying utilisation (e.g. number of visits, number of drug dispensings).
Examples
if (FALSE) { # \dontrun{
spec <- omop.feature.count(c(9201, 9202, 9203))
plan <- ds.omop.plan.features(plan, "visit_counts",
"visit_occurrence", specs = list(n_visits = spec))
} # }