Create a distinct concept count feature specification
Source:R/feature.R
omop.feature.n_distinct.RdProduces a feature spec that counts the number of distinct concept IDs per person across all records in the table. Unlike other features, this operates across all concepts rather than per-concept.
Usage
omop.feature.n_distinct(concept_set = integer(0), name = NULL)Examples
if (FALSE) { # \dontrun{
spec <- omop.feature.n_distinct()
plan <- ds.omop.plan.features(plan, "diversity",
"condition_occurrence", specs = list(n_conditions = spec))
} # }