Compiles a recipe to a plan and calls ds.omop.plan.preview.
This keeps the plan layer available for advanced users while allowing the
usual recipe workflow to stay one-step.
Compiles a recipe to a plan and calls ds.omop.plan.preview.
This keeps the plan layer available for advanced users while allowing the
usual recipe workflow to stay one-step.